==> codeready-workspaces-devfileregistry-rhel8-container-2.1-72.tar.gz: CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [3.1.1](https://github.com/nodeshift-starters/nodejs-configmap/compare/v3.1.0...v3.1.1) (2019-11-26)

## [3.1.0](https://github.com/nodeshift-starters/nodejs-configmap/compare/v3.0.0...v3.1.0) (2019-06-04)


### Features

* remove winston and start using pino for logging ([#86](https://github.com/nodeshift-starters/nodejs-configmap/issues/86)) ([5f95380](https://github.com/nodeshift-starters/nodejs-configmap/commit/5f95380))



<a name="3.0.0"></a>
# [3.0.0](https://github.com/nodeshift-starters/nodejs-configmap/compare/v2.1.1...v3.0.0) (2019-05-31)


### Features

*  Update to use Node.js 12.x ([9939f14](https://github.com/nodeshift-starters/nodejs-configmap/commit/9939f14))


### BREAKING CHANGES

* start using node 12



<a name="2.1.1"></a>
## [2.1.1](https://github.com/nodeshift-starters/nodejs-configmap/compare/v2.1.0...v2.1.1) (2019-04-15)



<a name="2.1.0"></a>
# [2.1.0](https://github.com/nodeshift-starters/nodejs-configmap/compare/v2.0.1...v2.1.0) (2018-11-16)


### Features

* Mount ConfigMaps as a Volume. ([#69](https://github.com/nodeshift-starters/nodejs-configmap/issues/69)) ([c50465d](https://github.com/nodeshift-starters/nodejs-configmap/commit/c50465d))



<a name="2.0.1"></a>
## [2.0.1](https://github.com/nodeshift-starters/nodejs-configmap/compare/v2.0.0...v2.0.1) (2018-11-08)


### Bug Fixes

* travis-ci should use npm install instead of npm ci ([89404e4](https://github.com/nodeshift-starters/nodejs-configmap/commit/89404e4))



<a name="2.0.0"></a>
# [2.0.0](https://github.com/nodeshift-starters/nodejs-configmap/compare/v1.2.3...v2.0.0) (2018-05-16)


### Features

* start using node.js 10. ([fae846a](https://github.com/nodeshift-starters/nodejs-configmap/commit/fae846a)), closes [#48](https://github.com/nodeshift-starters/nodejs-configmap/issues/48)



<a name="1.2.3"></a>
## [1.2.3](https://github.com/nodeshift-starters/nodejs-configmap/compare/v1.2.2...v1.2.3) (2018-04-26)


### Bug Fixes

* **www:** debug should take the project name as a parameter ([87374ef](https://github.com/nodeshift-starters/nodejs-configmap/commit/87374ef))
* remove port from start script ([0778b26](https://github.com/nodeshift-starters/nodejs-configmap/commit/0778b26))
* use the main prop for the application entry point. ([d94ab6f](https://github.com/nodeshift-starters/nodejs-configmap/commit/d94ab6f)), closes [nodeshift-starters/centos7-s2i-nodejs#33](https://github.com/nodeshift-starters/centos7-s2i-nodejs/issues/33) [#issuecomment-382587104](https://github.com/nodeshift-starters/nodejs-configmap/issues/issuecomment-382587104) [#45](https://github.com/nodeshift-starters/nodejs-configmap/issues/45)



<a name="1.2.2"></a>
## [1.2.2](https://github.com/nodeshift-starters/nodejs-configmap/compare/v1.2.1...v1.2.2) (2018-04-16)



<a name="1.2.1"></a>
## [1.2.1](https://github.com/nodeshift-starters/nodejs-configmap/compare/v1.2.0...v1.2.1) (2018-03-07)


### Bug Fixes

* **package:** need to run the licenser after the version bump ([679ef24](https://github.com/nodeshift-starters/nodejs-configmap/commit/679ef24))



<a name="1.2.0"></a>
# [1.2.0](https://github.com/nodeshift-starters/nodejs-configmap/compare/v1.1.2...v1.2.0) (2018-03-07)


### Bug Fixes

* **application.yaml:** docker tag should be 8.x ([f4b6390](https://github.com/nodeshift-starters/nodejs-configmap/commit/f4b6390))
* **package:** update openshift-rest-client to version 1.0.0 ([238080c](https://github.com/nodeshift-starters/nodejs-configmap/commit/238080c))


### Features

* **package:** Move nsp check from prepare step to an optional script. ([#32](https://github.com/nodeshift-starters/nodejs-configmap/issues/32)) ([192de76](https://github.com/nodeshift-starters/nodejs-configmap/commit/192de76)), closes [#31](https://github.com/nodeshift-starters/nodejs-configmap/issues/31)

==> codeready-workspaces-devfileregistry-rhel8-container-2.5-65.tar.gz: CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

## [4.0.0](https://github.com/nodeshift-starters/nodejs-configmap/compare/v3.1.2...v4.0.0) (2020-11-26)


### Features

* upgrade pino from 5.13.6 to 6.3.2 ([#137](https://github.com/nodeshift-starters/nodejs-configmap/issues/137)) ([e712b1f](https://github.com/nodeshift-starters/nodejs-configmap/commit/e712b1ff371a90a76f85ca37bc2f6fa33a180ff8))
* upgrade tape from 4.13.2 to 5.0.1 ([#138](https://github.com/nodeshift-starters/nodejs-configmap/issues/138)) ([f78153d](https://github.com/nodeshift-starters/nodejs-configmap/commit/f78153d034c4d9a22701458d47b343a91189e412))


### Bug Fixes

* package.json & package-lock.json to reduce vulnerabilities ([#130](https://github.com/nodeshift-starters/nodejs-configmap/issues/130)) ([f2f22c1](https://github.com/nodeshift-starters/nodejs-configmap/commit/f2f22c1395edba757824a7a7634f0ce81f9b02ec))
* package.json & package-lock.json to reduce vulnerabilities ([#134](https://github.com/nodeshift-starters/nodejs-configmap/issues/134)) ([9a35417](https://github.com/nodeshift-starters/nodejs-configmap/commit/9a35417f5ffd66dbf24ef6581f2e54f3c5246a1f))
* upgrade coveralls from 3.0.11 to 3.1.0 ([#132](https://github.com/nodeshift-starters/nodejs-configmap/issues/132)) ([d102f89](https://github.com/nodeshift-starters/nodejs-configmap/commit/d102f89380d75f0517d5e34b77b42578125a6d95))
* upgrade coveralls from 3.0.9 to 3.0.11 ([#127](https://github.com/nodeshift-starters/nodejs-configmap/issues/127)) ([1a87e37](https://github.com/nodeshift-starters/nodejs-configmap/commit/1a87e37abdf990be4291bc51fa32c529cc5bc561))
* upgrade debug from 4.1.1 to 4.2.0 ([#129](https://github.com/nodeshift-starters/nodejs-configmap/issues/129)) ([9615d7a](https://github.com/nodeshift-starters/nodejs-configmap/commit/9615d7ab5e853ef0deff672e3908ddd4b041c444))
* upgrade js-yaml from 3.13.1 to 3.14.0 ([#133](https://github.com/nodeshift-starters/nodejs-configmap/issues/133)) ([466bc38](https://github.com/nodeshift-starters/nodejs-configmap/commit/466bc384f50ae7ca511bbcc98859bf54bf935ff0))
* upgrade kube-probe from 0.4.0 to 0.5.0 ([#140](https://github.com/nodeshift-starters/nodejs-configmap/issues/140)) ([a3b4631](https://github.com/nodeshift-starters/nodejs-configmap/commit/a3b463149d1cf09287a321d4148809e4efef224e))
* upgrade nodeshift from 6.0.2 to 6.2.0 ([#139](https://github.com/nodeshift-starters/nodejs-configmap/issues/139)) ([bc7c4fb](https://github.com/nodeshift-starters/nodejs-configmap/commit/bc7c4fb321b4c6c7a8167838f84e1352d5856d59))

### [3.1.2](https://github.com/nodeshift-starters/nodejs-configmap/compare/v3.1.1...v3.1.2) (2020-04-27)

### [3.1.1](https://github.com/nodeshift-starters/nodejs-configmap/compare/v3.1.0...v3.1.1) (2019-11-26)

## [3.1.0](https://github.com/nodeshift-starters/nodejs-configmap/compare/v3.0.0...v3.1.0) (2019-06-04)


### Features

* remove winston and start using pino for logging ([#86](https://github.com/nodeshift-starters/nodejs-configmap/issues/86)) ([5f95380](https://github.com/nodeshift-starters/nodejs-configmap/commit/5f95380))



<a name="3.0.0"></a>
# [3.0.0](https://github.com/nodeshift-starters/nodejs-configmap/compare/v2.1.1...v3.0.0) (2019-05-31)


### Features

*  Update to use Node.js 12.x ([9939f14](https://github.com/nodeshift-starters/nodejs-configmap/commit/9939f14))


### BREAKING CHANGES

* start using node 12



<a name="2.1.1"></a>
## [2.1.1](https://github.com/nodeshift-starters/nodejs-configmap/compare/v2.1.0...v2.1.1) (2019-04-15)



<a name="2.1.0"></a>
# [2.1.0](https://github.com/nodeshift-starters/nodejs-configmap/compare/v2.0.1...v2.1.0) (2018-11-16)


### Features

* Mount ConfigMaps as a Volume. ([#69](https://github.com/nodeshift-starters/nodejs-configmap/issues/69)) ([c50465d](https://github.com/nodeshift-starters/nodejs-configmap/commit/c50465d))



<a name="2.0.1"></a>
## [2.0.1](https://github.com/nodeshift-starters/nodejs-configmap/compare/v2.0.0...v2.0.1) (2018-11-08)


### Bug Fixes

* travis-ci should use npm install instead of npm ci ([89404e4](https://github.com/nodeshift-starters/nodejs-configmap/commit/89404e4))



<a name="2.0.0"></a>
# [2.0.0](https://github.com/nodeshift-starters/nodejs-configmap/compare/v1.2.3...v2.0.0) (2018-05-16)


### Features

* start using node.js 10. ([fae846a](https://github.com/nodeshift-starters/nodejs-configmap/commit/fae846a)), closes [#48](https://github.com/nodeshift-starters/nodejs-configmap/issues/48)



<a name="1.2.3"></a>
## [1.2.3](https://github.com/nodeshift-starters/nodejs-configmap/compare/v1.2.2...v1.2.3) (2018-04-26)


### Bug Fixes

* **www:** debug should take the project name as a parameter ([87374ef](https://github.com/nodeshift-starters/nodejs-configmap/commit/87374ef))
* remove port from start script ([0778b26](https://github.com/nodeshift-starters/nodejs-configmap/commit/0778b26))
* use the main prop for the application entry point. ([d94ab6f](https://github.com/nodeshift-starters/nodejs-configmap/commit/d94ab6f)), closes [nodeshift-starters/centos7-s2i-nodejs#33](https://github.com/nodeshift-starters/centos7-s2i-nodejs/issues/33) [#issuecomment-382587104](https://github.com/nodeshift-starters/nodejs-configmap/issues/issuecomment-382587104) [#45](https://github.com/nodeshift-starters/nodejs-configmap/issues/45)



<a name="1.2.2"></a>
## [1.2.2](https://github.com/nodeshift-starters/nodejs-configmap/compare/v1.2.1...v1.2.2) (2018-04-16)



<a name="1.2.1"></a>
## [1.2.1](https://github.com/nodeshift-starters/nodejs-configmap/compare/v1.2.0...v1.2.1) (2018-03-07)


### Bug Fixes

* **package:** need to run the licenser after the version bump ([679ef24](https://github.com/nodeshift-starters/nodejs-configmap/commit/679ef24))



<a name="1.2.0"></a>
# [1.2.0](https://github.com/nodeshift-starters/nodejs-configmap/compare/v1.1.2...v1.2.0) (2018-03-07)


### Bug Fixes

* **application.yaml:** docker tag should be 8.x ([f4b6390](https://github.com/nodeshift-starters/nodejs-configmap/commit/f4b6390))
* **package:** update openshift-rest-client to version 1.0.0 ([238080c](https://github.com/nodeshift-starters/nodejs-configmap/commit/238080c))


### Features

* **package:** Move nsp check from prepare step to an optional script. ([#32](https://github.com/nodeshift-starters/nodejs-configmap/issues/32)) ([192de76](https://github.com/nodeshift-starters/nodejs-configmap/commit/192de76)), closes [#31](https://github.com/nodeshift-starters/nodejs-configmap/issues/31)
